<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>CircleConcentric</name>
    <message>
        <location filename="../CircleConcentric.ui" line="+17"/>
        <source>Distance:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Odległość: %1
Zaznacz obiekt do przycięcia lub wprowadź odległość:</translatorcomment>
        <translation>Odległość:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Number:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź liczbę:
Liczba:</translatorcomment>
        <translation>Ilość:</translation>
    </message>
    <message>
        <location filename="../CircleConcentricInit.js" line="+2"/>
        <source>&amp;Concentric (with Distance)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Koncentryczny (w odległości)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw concentric circle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rysuje koncentryczny okrąg</translation>
    </message>
</context>
</TS>
